@@ -225,8 +225,11 @@ def load(lib, IM_VERSION):
         except AttributeError:
             lib.MagickCompareImageLayers = None
     else:
-        lib.MagickCompareImagesLayers.argtypes = [c_void_p, c_int]
-        lib.MagickCompareImagesLayers.restype = c_void_p
+        try:
+            lib.MagickCompareImagesLayers.argtypes = [c_void_p, c_int]
+            lib.MagickCompareImagesLayers.restype = c_void_p
+        except AttributeError:
+            lib.MagickCompareImagesLayers = None
     if IM_VERSION >= 0x708:
         try:
             lib.MagickComplexImages.argtypes = [c_void_p, c_int]
@@ -512,6 +515,11 @@ def load(lib, IM_VERSION):
         lib.MagickGetImageKurtosis.restype = c_bool
     lib.MagickGetImageLength.argtypes = [c_void_p, POINTER(c_size_t)]
     lib.MagickGetImageLength.restype = c_bool
+    if is_im_7:
+        lib.MagickGetImageMask.argtypes = [c_void_p, c_int]
+        lib.MagickGetImageMask.restype = c_void_p
+    else:
+        lib.MagickGetImageMask = None
     lib.MagickGetImageMatteColor.argtypes = [c_void_p, c_void_p]
     lib.MagickGetImageMatteColor.restype = c_bool
     if is_im_7:
@@ -661,6 +669,11 @@ def load(lib, IM_VERSION):
         c_void_p, c_size_t, c_size_t, c_double, c_double
     ]
     lib.MagickLiquidRescaleImage.restype = c_bool
+    try:
+        lib.MagickLocalContrastImage.argtypes = [c_void_p, c_double, c_double]
+        lib.MagickLocalContrastImage.restype = c_bool
+    except AttributeError:
+        lib.MagickLocalContrastImage = None
     lib.MagickMagnifyImage.argtypes = [c_void_p]
     lib.MagickMagnifyImage.restype = c_bool
     if IM_VERSION >= 0x708:
@@ -752,6 +765,9 @@ def load(lib, IM_VERSION):
         lib.MagickOptimizeImageTransparency.restype = c_bool
     except AttributeError:
         lib.MagickOptimizeImageTransparency = None
+    if is_im_7:
+        lib.MagickOrderedDitherImage.argtypes = [c_void_p, c_char_p]
+        lib.MagickOrderedDitherImage.restype = c_bool
     if is_im_6:
         lib.MagickOrderedPosterizeImage.argtypes = [c_void_p, c_char_p]
         lib.MagickOrderedPosterizeImage.restype = c_bool
@@ -965,6 +981,11 @@ def load(lib, IM_VERSION):
     lib.MagickSetImageInterpolateMethod.restype = c_bool
     lib.MagickSetImageIterations.argtypes = [c_void_p, c_size_t]
     lib.MagickSetImageIterations.restype = c_bool
+    if is_im_7:
+        lib.MagickSetImageMask.argtypes = [c_void_p, c_int, c_void_p]
+        lib.MagickSetImageMask.restype = c_bool
+    else:
+        lib.MagickSetImageMask = None
     lib.MagickSetImageMatte.argtypes = [c_void_p, c_bool]
     lib.MagickSetImageMatteColor.argtypes = [c_void_p, c_void_p]
     if is_im_6:
@@ -1103,8 +1124,12 @@ def load(lib, IM_VERSION):
     lib.MagickStereoImage.restype = c_void_p
     lib.MagickStripImage.argtypes = [c_void_p]
     lib.MagickStripImage.restype = c_bool
-    lib.MagickSwirlImage.argtypes = [c_void_p, c_double]
-    lib.MagickSwirlImage.restype = c_bool
+    if is_im_6:
+        lib.MagickSwirlImage.argtypes = [c_void_p, c_double]
+        lib.MagickSwirlImage.restype = c_bool
+    else:
+        lib.MagickSwirlImage.argtypes = [c_void_p, c_double, c_int]
+        lib.MagickSwirlImage.restype = c_bool
     lib.MagickTextureImage.argtypes = [c_void_p, c_void_p]
     lib.MagickTextureImage.restype = c_void_p
     lib.MagickTintImage.argtypes = [c_void_p, c_void_p, c_void_p]
